/***비정규직 규모를 추산하는 방법***/ 

clear
cd "D:\klips\Stata"

use klips22p, replace 

// 임금근로자만 추출 //

// jobtype: 일자리형태(임금/비임금) 
keep if jobtype == 1


/**한시적근로자 (foe11)**/ 


* 근로계약기간을 정한 근로자 또는 정하지는 않았으나 계약을 반복 갱신해서 계속 일할 수 있는 근로자(기간제근로자)와 비자발적 사유로 계속 근무를 기대할 수 없는 근로자(비기간제근로자)를 포함


/*기간제 근로자 (foe111)*/ 

* 근로계약기간을 정한 근로자 계약직, 임시직, 촉탁징 등 근로의 명칭과 관계없이 근로계약 기간이 정해져 있는 경우

* p**0501: 근로계약기간 유무 (1=정해져 있다)

qui gen foe111=0
qui replace foe111=1 if p220501==1
tab foe111
label var foe111 "기간제근로자"

/*비기간제 근로자 (foe112)*/ 

// 근로계약기간을 정하지는 않았으나 계약을 반복 갱신해서 일할 수 있는 근로자 또는 비자발적 사유로 계속 근무를 기대할 수 없는 근로자

// p**0501: 근로계약기간 유무 (2=정해져 있지 않다)
// p**0601: 고용안정성 (2=아니요)
// p**0602: 고용 안정성 이유 (2=계약의 반복,갱신으로 고용이 지속되고 있으므로)
// p**0605: 고용불안정 이유

qui gen foe112=0
qui replace foe112=1 if p220501==2 & p220601==1 & p220602==2
qui replace foe112=1 if p220501==2 & p220601==2 & (p220605==1 | p220605==2 | p220605==3 | p220605==4 | p220605==5 | p220605==6)
tab foe112
label var foe112 "비기간제근로자"

qui gen foe11 = 0 
qui replace foe11 = 1 if foe111+foe112 > 0 
tab foe11
label var foe11 "한시적근로자"


/**시간제근로자 (foe12)**/ 

// 근로시간이 짧은 파트타임 근로자

// p**0315: 근로시간형태(시간제/전일제)

qui gen foe12=0
qui replace foe12=1 if p220315==1
tab foe12
label var foe12 "시간제근로자"


/**비전형 근로자 (foe13)**/

// 파견근로자, 용역근로자, 특수형태근로종사자, 가정내(재택, 가내)근로자, 일일(단기) 근로자 등


/*파견근로자 (foe131)*/ 

// 임금을 지급하고 고용관계가 유지되는 고용주와 업무지시를 하는 사용자가 일치히자 않는 경우로 파견사업주가 근로자를 고용한 후 그 고용관계를 유지하면서 근로자 파견계약의 내용에 따라 사용사업주의 사업장에서 지휘, 명령을 받아 사용사업주를 위하여 근무하는 형태

// p**0611: 파견 및 용역근로여부 (2=파견업체) 

qui gen foe131=0
qui replace foe131=1 if p220611==2
tab foe131
label var foe131 "파견근로자"

/*용역근로자 (foe132)*/

// 용역업체에 고용되어 이 업체의 지휘하에 이 업체와 용역계약을 맺은 다른 업체에서 근무하는 형태

// p**0611: 파견 및 용역근로여부 (3=용역업체)

qui gen foe132=0
qui replace foe132=1 if p220611==3
tab foe132
label var foe132 "용역근로자"

/*특수형태노동종사자 (foe133)*/ 

// 독자적인 사무실, 점포 또는 작업장을 보유하지 않았으면서 비독립적인 형태로 업무를 수행하면서도, 다만 근로제공의 방법, 근로시간 등은 독자적으로 결정하면서, 개인적으로 모집, 배달, 운송 등의 업무를 통해 고객을 찾거나 맞이하여 상품이나 서비스를 제공하고 그 일을 한만큼 소득을 얻는 근무형태

// p**0612: 독립도급여부

qui gen foe133=0
qui replace foe133=1 if p220612==1
tab foe133
label var foe133 "특수형태근로종사자"

/*가정내근로자 (foe134)*/ 

// 재택근무, 가내하청 등과 같이 사업체에서 마련해 주 공동작업장이 아닌 강정내에서 근무가 이루어지는 근무형태

* p**0613: 가내근로여부

qui gen foe134=0
qui replace foe134=1 if p220613==1
tab foe134
label var foe134 "가정내근로자"

/*일일(단기)근로자 (foe135)*/

// 근로계약을 정하지 않고, 일거리가 생겼을 경우 며칠 또는 몇 주씩 일하는 형태의 근로자

// p**0508: 불규칙적 일자리

qui gen foe135=0
qui replace foe135=1 if p220508==1
tab foe135
label var foe135 "일일단기근로자"

qui gen foe13=0 
qui replace foe13 = 1 if foe131+foe132+foe133+foe134+foe135 > 0 
tab foe13
label var foe13 "비전형근로자"


/**노사정위원회 기준 비정규직 (foe1)**/ 

// 한시적, 시간제, 비전형 근로자에 포함되는 근로자

qui gen foe1=0
qui replace foe1=1 if foe11+foe12+foe13>0
tab foe1
label var foe1 "노사정 위원회 기준 비정규직"

/**종사상지위 기준 비정규직 (foe2)**/ 

// 종사상지위가 임시직, 일용직에 포함되는 근로자

// p**0314: 종사상지위(1=상용직,2=임시직,3=일용직,4=고용주/자영업자,5=무급가족종사자)

qui gen foe2=0
qui replace foe2=1 if p220314==2 | p220314==3
tab foe2
label var foe2 "종사상지위 비정규직"

/**자기선언적 비정규직 (foe3)**/ 

// p**0317: 정규직/비정규직 여부

qui gen foe3=0
qui replace foe3=1 if p220317==2
tab foe3
label var foe3 "자기선언적 비정규직"

save "D:\klips\Stata\data\exaple.dta", replace 